aboutsummaryrefslogtreecommitdiffstats
path: root/core/test
diff options
context:
space:
mode:
Diffstat (limited to 'core/test')
-rw-r--r--core/test/app.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/core/test/app.go b/core/test/app.go
index 60b74ac..76f1a10 100644
--- a/core/test/app.go
+++ b/core/test/app.go
@@ -102,9 +102,9 @@ func NewApp() *App {
}
}
-// PreparePayloads implements Application interface.
-func (app *App) PreparePayloads(position types.Position) [][]byte {
- return [][]byte{}
+// PreparePayload implements Application interface.
+func (app *App) PreparePayload(position types.Position) []byte {
+ return []byte{}
}
// VerifyPayloads implements Application.